@@ -18,6 +18,7 @@ wrdiropt=
 . $bindir/wrdir-def.h
 f_opt=
 y_opt=
+R_opt=
 
 usage_msg=`cat <<EOF
 No parameters are needed.
@@ -32,6 +33,7 @@ Options:
 -y        Answer to all prompts is y.
 -wrdir d  Set the writable directory.  This dir is needed to hold some temp 
           files.  
+-R        Do not reboot after successful reflashing.
 EOF
 `
 while [ -n "$*" ]
@@ -56,6 +58,9 @@ do
 	-h|-help|--help)
 	    usage
 	    ;;
+	-R)
+	    R_opt='-R'
+	    ;;
 	*)
 	    emsg "Unsupported option >$1<"
 	    usage
@@ -79,4 +84,4 @@ case "$arch" in
 	;;
 esac
 
-exec $exe $y_opt $f_opt -c $bindir/rewince-z.ref -c $bindir/rewince.ref $just_show
+exec $exe $y_opt $f_opt $R_opt -c $bindir/rewince-z.ref -c $bindir/rewince.ref $just_show
